@@ -15,12 +15,9 @@ use crate::messaging::{
     WireMsg,
 };
 use crate::routing::{
-    error::Result,
-    peer::PeerUtils,
-    relocation::RelocatePayloadUtils,
-    routing_api::command::Command,
-    section::{SectionPeersUtils, SectionUtils},
-    FIRST_SECTION_MAX_AGE, FIRST_SECTION_MIN_AGE, MIN_ADULT_AGE,
+    error::Result, peer::PeerUtils, relocation::RelocatePayloadUtils,
+    routing_api::command::Command, section::SectionPeersUtils, FIRST_SECTION_MAX_AGE,
+    FIRST_SECTION_MIN_AGE, MIN_ADULT_AGE,
 };
 use bls::PublicKey as BlsPublicKey;
 
